From 66ac2064fecff1cc95b47bf91217faced601d20b Mon Sep 17 00:00:00 2001
From: xjm <xjm@65776.no-reply.drupal.org>
Date: Mon, 16 Jan 2023 10:36:05 -0600
Subject: [PATCH] Issue #3185640 by lucienchalom, jungle, smustgrave,
 ravi.shankar, andregp, xjm, quietone, sergiogsanchez: Fix or ignore words
 that start with "v", excluding real non-English words

---
 .../Transliteration/PhpTransliteration.php    |  2 ++
 core/misc/cspell/dictionary.txt               |  7 -----
 .../src/BigPipePlaceholderTestCases.php       | 14 +++++----
 core/modules/block/js/block.js                | 10 +++----
 .../ckeditor5/src/HTMLRestrictions.php        |  1 +
 .../Functional/ConfigTranslationUiTest.php    |  2 ++
 .../filter/src/Plugin/Filter/FilterHtml.php   |  1 +
 .../locale_test_development_release.info.yml  |  2 +-
 core/modules/media/js/type_form.js            | 18 ++++++-----
 core/modules/node/content_types.js            | 30 +++++++++----------
 core/modules/node/node.js                     |  6 ++--
 .../pgsql/tests/src/Unit/SchemaTest.php       |  2 +-
 .../Plugin/views/field/TaxonomyIndexTid.php   |  6 ++--
 core/modules/taxonomy/src/TermStorage.php     |  6 ++--
 .../taxonomy/src/TermStorageInterface.php     |  8 ++---
 15 files changed, 59 insertions(+), 56 deletions(-)

diff --git a/core/lib/Drupal/Component/Transliteration/PhpTransliteration.php b/core/lib/Drupal/Component/Transliteration/PhpTransliteration.php
index 3f1d9253da85..7aab75001b71 100644
--- a/core/lib/Drupal/Component/Transliteration/PhpTransliteration.php
+++ b/core/lib/Drupal/Component/Transliteration/PhpTransliteration.php
@@ -2,6 +2,8 @@
 
 namespace Drupal\Component\Transliteration;
 
+// cspell:ignore vibber
+
 /**
  * Implements transliteration without using the PECL extensions.
  *
diff --git a/core/misc/cspell/dictionary.txt b/core/misc/cspell/dictionary.txt
index ca55c6d86c2a..1d502548c095 100644
--- a/core/misc/cspell/dictionary.txt
+++ b/core/misc/cspell/dictionary.txt
@@ -1392,26 +1392,19 @@ userref
 userreference
 userspace
 usuario
-vals
 vampirize
 varchar
-veeeery
 veniam
-verison
 versionable
 versionless
 verygreatdrupalmodule
 vfsstream
-vibber
 viewmode
 viewports
-viewsviewfiles
 vocabs
 volgende
 vorige
 vous
-vxezb
-vxfbk
 wcprops
 webassert
 webcal
diff --git a/core/modules/big_pipe/tests/modules/big_pipe_test/src/BigPipePlaceholderTestCases.php b/core/modules/big_pipe/tests/modules/big_pipe_test/src/BigPipePlaceholderTestCases.php
index c376676a9699..22d1da8f1ee9 100644
--- a/core/modules/big_pipe/tests/modules/big_pipe_test/src/BigPipePlaceholderTestCases.php
+++ b/core/modules/big_pipe/tests/modules/big_pipe_test/src/BigPipePlaceholderTestCases.php
@@ -274,35 +274,37 @@ public static function cases(ContainerInterface $container = NULL, AccountInterf
     ];
     $exception->embeddedHtmlResponse = NULL;
 
+    // cSpell:disable-next-line.
+    $token = 'PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU';
     // 7. Edge case: response filter throwing an exception for this placeholder.
     $embedded_response_exception = new BigPipePlaceholderTestCase(
       [
         '#lazy_builder' => ['\Drupal\big_pipe_test\BigPipeTestController::responseException', []],
         '#create_placeholder' => TRUE,
       ],
-      '<drupal-render-placeholder callback="\Drupal\big_pipe_test\BigPipeTestController::responseException" arguments="" token="PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU"></drupal-render-placeholder>',
+      '<drupal-render-placeholder callback="\Drupal\big_pipe_test\BigPipeTestController::responseException" arguments="" token="' . $token . ' "></drupal-render-placeholder>',
       [
         '#lazy_builder' => ['\Drupal\big_pipe_test\BigPipeTestController::responseException', []],
       ]
     );
-    $embedded_response_exception->bigPipePlaceholderId = 'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU';
+    $embedded_response_exception->bigPipePlaceholderId = 'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=' . $token;
     $embedded_response_exception->bigPipePlaceholderRenderArray = [
-      '#markup' => '<span data-big-pipe-placeholder-id="callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU"></span>',
+      '#markup' => '<span data-big-pipe-placeholder-id="callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=' . $token . '"></span>',
       '#cache' => $cacheability_depends_on_session_and_nojs_cookie,
       '#attached' => [
         'library' => ['big_pipe/big_pipe'],
         'drupalSettings' => [
           'bigPipePlaceholderIds' => [
-            'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&&token=PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU' => TRUE,
+            'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&&token=' . $token => TRUE,
           ],
         ],
         'big_pipe_placeholders' => [
-          'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU' => $embedded_response_exception->placeholderRenderArray,
+          'callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=' . $token => $embedded_response_exception->placeholderRenderArray,
         ],
       ],
     ];
     $embedded_response_exception->embeddedAjaxResponseCommands = NULL;
-    $embedded_response_exception->bigPipeNoJsPlaceholder = '<span data-big-pipe-nojs-placeholder-id="callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=PxOHfS_QL-T01NjBgu7Z7I04tIwMp6La5vM-mVxezbU"></span>';
+    $embedded_response_exception->bigPipeNoJsPlaceholder = '<span data-big-pipe-nojs-placeholder-id="callback=%5CDrupal%5Cbig_pipe_test%5CBigPipeTestController%3A%3AresponseException&amp;&amp;token=' . $token . '"></span>';
     $embedded_response_exception->bigPipeNoJsPlaceholderRenderArray = [
       '#markup' => $embedded_response_exception->bigPipeNoJsPlaceholder,
       '#cache' => $cacheability_depends_on_session_and_nojs_cookie,
diff --git a/core/modules/block/js/block.js b/core/modules/block/js/block.js
index a642ce363e6b..7f03b99a8bdf 100644
--- a/core/modules/block/js/block.js
+++ b/core/modules/block/js/block.js
@@ -31,18 +31,18 @@
        *   A string with the summary.
        */
       function checkboxesSummary(context) {
-        const vals = [];
+        const values = [];
         const $checkboxes = $(context).find(
           'input[type="checkbox"]:checked + label',
         );
         const il = $checkboxes.length;
         for (let i = 0; i < il; i++) {
-          vals.push($($checkboxes[i]).html());
+          values.push($($checkboxes[i]).html());
         }
-        if (!vals.length) {
-          vals.push(Drupal.t('Not restricted'));
+        if (!values.length) {
+          values.push(Drupal.t('Not restricted'));
         }
-        return vals.join(', ');
+        return values.join(', ');
       }
 
       $(
diff --git a/core/modules/ckeditor5/src/HTMLRestrictions.php b/core/modules/ckeditor5/src/HTMLRestrictions.php
index 68cd0589e537..238d412c1708 100644
--- a/core/modules/ckeditor5/src/HTMLRestrictions.php
+++ b/core/modules/ckeditor5/src/HTMLRestrictions.php
@@ -559,6 +559,7 @@ public static function fromString(string $elements_string): HTMLRestrictions {
     unset($allowed_elements['*']);
     // @see \Drupal\filter\Plugin\Filter\FilterHtml::getHTMLRestrictions()
     // @todo remove this in https://www.drupal.org/project/drupal/issues/3226368
+    // cSpell:disable-next-line
     unset($allowed_elements['__zqh6vxfbk3cg__']);
 
     // Postprocess tag wildcards: convert
diff --git a/core/modules/config_translation/tests/src/Functional/ConfigTranslationUiTest.php b/core/modules/config_translation/tests/src/Functional/ConfigTranslationUiTest.php
index f60c0a56ee56..2cf729b9822b 100644
--- a/core/modules/config_translation/tests/src/Functional/ConfigTranslationUiTest.php
+++ b/core/modules/config_translation/tests/src/Functional/ConfigTranslationUiTest.php
@@ -13,6 +13,8 @@
 use Drupal\node\Entity\NodeType;
 use Drupal\Tests\BrowserTestBase;
 
+// cspell:ignore viewsviewfiles
+
 /**
  * Translate settings and entities to various languages.
  *
diff --git a/core/modules/filter/src/Plugin/Filter/FilterHtml.php b/core/modules/filter/src/Plugin/Filter/FilterHtml.php
index 533c763e4627..e4474320c39b 100644
--- a/core/modules/filter/src/Plugin/Filter/FilterHtml.php
+++ b/core/modules/filter/src/Plugin/Filter/FilterHtml.php
@@ -256,6 +256,7 @@ public function getHTMLRestrictions() {
     $html = str_replace('>', ' />', $this->settings['allowed_html']);
     // Protect any trailing * characters in attribute names, since DomDocument
     // strips them as invalid.
+    // cSpell:disable-next-line
     $star_protector = '__zqh6vxfbk3cg__';
     $html = str_replace('*', $star_protector, $html);
     $body_child_nodes = Html::load($html)->getElementsByTagName('body')->item(0)->childNodes;
diff --git a/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml b/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
index 6ecdeabe9f07..d8dcb1f9ba96 100644
--- a/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
+++ b/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
@@ -1,6 +1,6 @@
 name: 'Locale Test Development Release'
 type: module
-description: 'Helper module to test the behavior when the core verison is a development release.'
+description: 'Helper module to test the behavior when the core version is a development release.'
 package: Testing
 version: VERSION
 hidden: true
diff --git a/core/modules/media/js/type_form.js b/core/modules/media/js/type_form.js
index f24d52b52e61..ebfe844aa30b 100644
--- a/core/modules/media/js/type_form.js
+++ b/core/modules/media/js/type_form.js
@@ -17,24 +17,26 @@
       const $context = $(context);
       // Provide the vertical tab summaries.
       $context.find('#edit-workflow').drupalSetSummary((context) => {
-        const vals = [];
+        const values = [];
         $(context)
           .find('input[name^="options"]:checked')
           .parent()
           .each(function () {
-            vals.push(Drupal.checkPlain($(this).find('label')[0].textContent));
+            values.push(
+              Drupal.checkPlain($(this).find('label')[0].textContent),
+            );
           });
         if (!$(context).find('#edit-options-status').is(':checked')) {
-          vals.unshift(Drupal.t('Not published'));
+          values.unshift(Drupal.t('Not published'));
         }
-        return vals.join(', ');
+        return values.join(', ');
       });
       $(context)
         .find('#edit-language')
         .drupalSetSummary((context) => {
-          const vals = [];
+          const values = [];
 
-          vals.push(
+          values.push(
             $(context).find(
               '.js-form-item-language-configuration-langcode select option:selected',
             )[0].textContent,
@@ -44,10 +46,10 @@
             .find('input:checked')
             .next('label')
             .each(function () {
-              vals.push(Drupal.checkPlain(this.textContent));
+              values.push(Drupal.checkPlain(this.textContent));
             });
 
-          return vals.join(', ');
+          return values.join(', ');
         });
     },
   };
diff --git a/core/modules/node/content_types.js b/core/modules/node/content_types.js
index b7650d1ef346..c663db8ef00c 100644
--- a/core/modules/node/content_types.js
+++ b/core/modules/node/content_types.js
@@ -17,30 +17,30 @@
       const $context = $(context);
       // Provide the vertical tab summaries.
       $context.find('#edit-submission').drupalSetSummary((context) => {
-        const vals = [];
-        vals.push(
+        const values = [];
+        values.push(
           Drupal.checkPlain($(context).find('#edit-title-label')[0].value) ||
             Drupal.t('Requires a title'),
         );
-        return vals.join(', ');
+        return values.join(', ');
       });
       $context.find('#edit-workflow').drupalSetSummary((context) => {
-        const vals = [];
+        const values = [];
         $(context)
           .find('input[name^="options"]:checked')
           .next('label')
           .each(function () {
-            vals.push(Drupal.checkPlain(this.textContent));
+            values.push(Drupal.checkPlain(this.textContent));
           });
         if (!$(context).find('#edit-options-status').is(':checked')) {
-          vals.unshift(Drupal.t('Not published'));
+          values.unshift(Drupal.t('Not published'));
         }
-        return vals.join(', ');
+        return values.join(', ');
       });
       $('#edit-language', context).drupalSetSummary((context) => {
-        const vals = [];
+        const values = [];
 
-        vals.push(
+        values.push(
           $(
             '.js-form-item-language-configuration-langcode select option:selected',
             context,
@@ -50,24 +50,24 @@
         $('input:checked', context)
           .next('label')
           .each(function () {
-            vals.push(Drupal.checkPlain(this.textContent));
+            values.push(Drupal.checkPlain(this.textContent));
           });
 
-        return vals.join(', ');
+        return values.join(', ');
       });
       $context.find('#edit-display').drupalSetSummary((context) => {
-        const vals = [];
+        const values = [];
         const $editContext = $(context);
         $editContext
           .find('input:checked')
           .next('label')
           .each(function () {
-            vals.push(Drupal.checkPlain(this.textContent));
+            values.push(Drupal.checkPlain(this.textContent));
           });
         if (!$editContext.find('#edit-display-submitted').is(':checked')) {
-          vals.unshift(Drupal.t("Don't display post information"));
+          values.unshift(Drupal.t("Don't display post information"));
         }
-        return vals.join(', ');
+        return values.join(', ');
       });
     },
   };
diff --git a/core/modules/node/node.js b/core/modules/node/node.js
index c9ed55068d32..74047c9ab2ba 100644
--- a/core/modules/node/node.js
+++ b/core/modules/node/node.js
@@ -38,16 +38,16 @@
 
       $context.find('.node-form-options').drupalSetSummary((context) => {
         const $optionsContext = $(context);
-        const vals = [];
+        const values = [];
 
         if ($optionsContext.find('input').is(':checked')) {
           $optionsContext
             .find('input:checked')
             .next('label')
             .each(function () {
-              vals.push(Drupal.checkPlain(this.textContent.trim()));
+              values.push(Drupal.checkPlain(this.textContent.trim()));
             });
-          return vals.join(', ');
+          return values.join(', ');
         }
 
         return Drupal.t('Not promoted');
diff --git a/core/modules/pgsql/tests/src/Unit/SchemaTest.php b/core/modules/pgsql/tests/src/Unit/SchemaTest.php
index 7673638143b2..3b9192fdea4e 100644
--- a/core/modules/pgsql/tests/src/Unit/SchemaTest.php
+++ b/core/modules/pgsql/tests/src/Unit/SchemaTest.php
@@ -74,7 +74,7 @@ public function providerComputedConstraintName() {
     return [
       ['user_field_data', 'pkey', 'user_field_data____pkey'],
       ['user_field_data', 'name__key', 'user_field_data__name__key'],
-      ['user_field_data', 'a_veeeery_veery_very_super_long_field_name__key', 'drupal_BGGYAXgbqlAF1rMOyFTdZGj9zIMXZtSvEjMAKZ9wGIk_key'],
+      ['user_field_data', 'a_very_very_very_very_super_long_field_name__key', 'drupal_WW_a8TlbZ3UQi20UTtRlJFaIeSa6FEtQS5h4NRA3UeU_key'],
     ];
   }
 
diff --git a/core/modules/taxonomy/src/Plugin/views/field/TaxonomyIndexTid.php b/core/modules/taxonomy/src/Plugin/views/field/TaxonomyIndexTid.php
index 805f56b8c28f..dc145a0e0fcb 100644
--- a/core/modules/taxonomy/src/Plugin/views/field/TaxonomyIndexTid.php
+++ b/core/modules/taxonomy/src/Plugin/views/field/TaxonomyIndexTid.php
@@ -135,11 +135,11 @@ public function preRender(&$values) {
     }
 
     if ($nids) {
-      $vocabs = array_filter($this->options['vids']);
+      $vids = array_filter($this->options['vids']);
       if (empty($this->options['limit'])) {
-        $vocabs = [];
+        $vids = [];
       }
-      $result = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->getNodeTerms($nids, $vocabs);
+      $result = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->getNodeTerms($nids, $vids);
 
       foreach ($result as $node_nid => $data) {
         foreach ($data as $tid => $term) {
diff --git a/core/modules/taxonomy/src/TermStorage.php b/core/modules/taxonomy/src/TermStorage.php
index c01ae66d3adb..061abd39e4ab 100644
--- a/core/modules/taxonomy/src/TermStorage.php
+++ b/core/modules/taxonomy/src/TermStorage.php
@@ -343,7 +343,7 @@ public function resetWeights($vid) {
   /**
    * {@inheritdoc}
    */
-  public function getNodeTerms(array $nids, array $vocabs = [], $langcode = NULL) {
+  public function getNodeTerms(array $nids, array $vids = [], $langcode = NULL) {
     $query = $this->database->select($this->getDataTable(), 'td');
     $query->innerJoin('taxonomy_index', 'tn', '[td].[tid] = [tn].[tid]');
     $query->fields('td', ['tid']);
@@ -352,8 +352,8 @@ public function getNodeTerms(array $nids, array $vocabs = [], $langcode = NULL)
     $query->orderby('td.name');
     $query->condition('tn.nid', $nids, 'IN');
     $query->addTag('taxonomy_term_access');
-    if (!empty($vocabs)) {
-      $query->condition('td.vid', $vocabs, 'IN');
+    if (!empty($vids)) {
+      $query->condition('td.vid', $vids, 'IN');
     }
     if (!empty($langcode)) {
       $query->condition('td.langcode', $langcode);
diff --git a/core/modules/taxonomy/src/TermStorageInterface.php b/core/modules/taxonomy/src/TermStorageInterface.php
index 41d521156aba..1f995204b280 100644
--- a/core/modules/taxonomy/src/TermStorageInterface.php
+++ b/core/modules/taxonomy/src/TermStorageInterface.php
@@ -118,16 +118,16 @@ public function resetWeights($vid);
    *
    * @param array $nids
    *   Node IDs to retrieve terms for.
    * @param array $vocabs
    *   (optional) A vocabularies array to restrict the term search. Defaults to
    *   empty array.
    * @param string $langcode
    *   (optional) A language code to restrict the term search. Defaults to NULL.
    *
    * @return array
    *   An array of nids and the term entities they were tagged with.
    */
-  public function getNodeTerms(array $nids, array $vocabs = [], $langcode = NULL);
+  public function getNodeTerms(array $nids, array $vids = [], $langcode = NULL);
 
   /**
    * Returns the hierarchy type for a specific vocabulary ID.
@@ -118,16 +118,16 @@ public function resetWeights($vid);
    * @param array $nids
    *   Node IDs to retrieve terms for.
-   * @param array $vocabs
-   *   (optional) A vocabularies array to restrict the term search. Defaults to
-   *   empty array.
+   * @param array $vids
+   *   (optional) an array of vocabulary IDs to restrict the term search.
+   *   Defaults to empty array.
    * @param string $langcode
    *   (optional) A language code to restrict the term search. Defaults to NULL.
-- 
GitLab